import { InjectionToken } from '@angular/core';
import { Observable, Subject } from 'rxjs';
export declare type DetectedTheme = 'dark' | 'light';
export declare type ThemeLoader = () => string | null;
export declare type ThemeSaver = (theme: string | null) => void;
/**
 * A function that loads the saved theme.
 * Defaults to loading from local storage with the key `theme`.
 */
export declare const THEME_LOADER: InjectionToken<ThemeLoader>;
/**
 * A function that saves the theme.
 * Defaults to saving to local storage with the key `theme`.
 */
export declare const THEME_SAVER: InjectionToken<ThemeSaver>;
export declare class ThemeService {
    private _theme;
    private readonly _loadHandler;
    private readonly _saveHandler;
    constructor(document: any, loadHandler: any, saveHandler: any);
    /**
     * @return a subject representing the currently active theme
     */
    get theme$(): Subject<string | null>;
    /**
     * @return `dark` if the user agent prefers dark color scheme, `light` otherwise
     */
    get detectedTheme(): DetectedTheme;
    /**
     * @return an observable version of {@link detectedTheme} that automatically updates on changes, e.g. when the user
     * changes their operating system theme preference, or it switches depending on day/night.
     */
    get detectedTheme$(): Observable<DetectedTheme>;
    /**
     * @return the current theme
     */
    get theme(): string | null;
    /**
     * @param value
     *  the new theme
     */
    set theme(value: string | null);
    /**
     * @return the saved theme, using {@link THEME_LOADER}
     */
    get savedTheme(): string | null;
    /**
     * @param theme
     *  the theme to save using {@link THEME_SAVER}
     */
    set savedTheme(theme: string | null);
}
